@@ -11,6 +11,8 @@ sns.set_theme(style="ticks")
 df = sns.load_dataset("anscombe")
 
 # Show the results of a linear regression within each dataset
-sns.lmplot(x="x", y="y", col="dataset", hue="dataset", data=df,
-           col_wrap=2, ci=None, palette="muted", height=4,
-           scatter_kws={"s": 50, "alpha": 1})
+sns.lmplot(
+    data=df, x="x", y="y", col="dataset", hue="dataset",
+    col_wrap=2, palette="muted", ci=None,
+    height=4, scatter_kws={"s": 50, "alpha": 1}
+)
