@@ -5,13 +5,12 @@ Grouped violinplots with split violins
 _thumb: .44, .47
 """
 import seaborn as sns
-sns.set_theme(style="whitegrid")
+sns.set_theme(style="dark")
 
 # Load the example tips dataset
 tips = sns.load_dataset("tips")
 
 # Draw a nested violinplot and split the violins for easier comparison
 sns.violinplot(data=tips, x="day", y="total_bill", hue="smoker",
-               split=True, inner="quart", linewidth=1,
-               palette={"Yes": "b", "No": ".85"})
-sns.despine(left=True)
+               split=True, inner="quart", fill=False,
+               palette={"Yes": "g", "No": ".35"})
