@@ -3,7 +3,6 @@ Conditional means with observations
 ===================================
 
 """
-import pandas as pd
 import seaborn as sns
 import matplotlib.pyplot as plt
 
@@ -11,7 +10,7 @@ sns.set_theme(style="whitegrid")
 iris = sns.load_dataset("iris")
 
 # "Melt" the dataset to "long-form" or "tidy" representation
-iris = pd.melt(iris, "species", var_name="measurement")
+iris = iris.melt(id_vars="species", var_name="measurement")
 
 # Initialize the figure
 f, ax = plt.subplots()
@@ -20,7 +19,7 @@ sns.despine(bottom=True, left=True)
 # Show each observation with a scatterplot
 sns.stripplot(
     data=iris, x="value", y="measurement", hue="species",
-    dodge=True, alpha=.25, zorder=1, legend=False
+    dodge=True, alpha=.25, zorder=1, legend=False,
 )
 
 # Show the conditional means, aligning each pointplot in the
@@ -28,11 +27,11 @@ sns.stripplot(
 # category (.8 by default) by the number of hue levels
 sns.pointplot(
     data=iris, x="value", y="measurement", hue="species",
-    join=False, dodge=.8 - .8 / 3, palette="dark",
-    markers="d", scale=.75, errorbar=None
+    dodge=.8 - .8 / 3, palette="dark", errorbar=None,
+    markers="d", markersize=4, linestyle="none",
 )
 
 # Improve the legend
 sns.move_legend(
-    ax, loc="lower right", ncol=3, frameon=True, columnspacing=1, handletextpad=0
+    ax, loc="lower right", ncol=3, frameon=True, columnspacing=1, handletextpad=0,
 )
