@@ -10,7 +10,7 @@ import pandas as pd
 import seaborn as sns
 import matplotlib.pyplot as plt
 
-sns.set(style="white")
+sns.set_theme(style="white")
 
 # Generate a large random dataset
 rs = np.random.RandomState(33)
@@ -21,13 +21,13 @@ d = pd.DataFrame(data=rs.normal(size=(100, 26)),
 corr = d.corr()
 
 # Generate a mask for the upper triangle
-mask = np.triu(np.ones_like(corr, dtype=np.bool))
+mask = np.triu(np.ones_like(corr, dtype=bool))
 
 # Set up the matplotlib figure
 f, ax = plt.subplots(figsize=(11, 9))
 
 # Generate a custom diverging colormap
-cmap = sns.diverging_palette(220, 10, as_cmap=True)
+cmap = sns.diverging_palette(230, 20, as_cmap=True)
 
 # Draw the heatmap with the mask and correct aspect ratio
 sns.heatmap(corr, mask=mask, cmap=cmap, vmax=.3, center=0,
