@@ -5,10 +5,10 @@ Linear regression with marginal distributions
 _thumb: .65, .65
 """
 import seaborn as sns
-sns.set(style="darkgrid")
+sns.set_theme(style="darkgrid")
 
 tips = sns.load_dataset("tips")
-g = sns.jointplot("total_bill", "tip", data=tips,
+g = sns.jointplot(x="total_bill", y="tip", data=tips,
                   kind="reg", truncate=False,
                   xlim=(0, 60), ylim=(0, 12),
                   color="m", height=7)
