@@ -2,10 +2,10 @@
 Scatterplot Matrix
 ==================
 
-_thumb: .5, .43
+_thumb: .3, .2
 """
 import seaborn as sns
-sns.set(style="ticks")
+sns.set_theme(style="ticks")
 
-df = sns.load_dataset("iris")
+df = sns.load_dataset("penguins")
 sns.pairplot(df, hue="species")
