@@ -1,6 +1,7 @@
 """Tests for seaborn utility functions."""
 import re
 import tempfile
+from types import ModuleType
 from urllib.request import urlopen
 from http.client import HTTPException
 
@@ -19,17 +20,19 @@ from pandas.testing import (
     assert_frame_equal,
 )
 
-from seaborn import utils, rcmod
-from seaborn.external.version import Version
+from seaborn import utils, rcmod, scatterplot
 from seaborn.utils import (
     get_dataset_names,
     get_color_cycle,
     remove_na,
     load_dataset,
     _assign_default_kwargs,
+    _check_argument,
     _draw_figure,
     _deprecate_ci,
+    _version_predates, DATASET_NAMES_URL,
 )
+from seaborn._compat import get_legend_handles
 
 
 a_norm = np.random.randn(100)
@@ -88,6 +91,9 @@ def test_desaturate():
     out4 = utils.desaturate("red", .5)
     assert out4 == (.75, .25, .25)
 
+    out5 = utils.desaturate("lightblue", 1)
+    assert out5 == mpl.colors.to_rgb("lightblue")
+
 
 def test_desaturation_prop():
     """Test that pct outside of [0, 1] raises exception."""
@@ -118,7 +124,7 @@ def test_saturate():
 def test_to_utf8(s, exp):
     """Test the to_utf8 function: object to string"""
     u = utils.to_utf8(s)
-    assert type(u) == str
+    assert isinstance(u, str)
     assert u == exp
 
 
@@ -139,13 +145,13 @@ class TestSpineUtils:
 
         utils.despine()
         for side in self.outer_sides:
-            assert ~ax.spines[side].get_visible()
+            assert not ax.spines[side].get_visible()
         for side in self.inner_sides:
             assert ax.spines[side].get_visible()
 
         utils.despine(**dict(zip(self.sides, [True] * 4)))
         for side in self.sides:
-            assert ~ax.spines[side].get_visible()
+            assert not ax.spines[side].get_visible()
 
     def test_despine_specific_axes(self):
         f, (ax1, ax2) = plt.subplots(2, 1)
@@ -156,7 +162,7 @@ class TestSpineUtils:
             assert ax1.spines[side].get_visible()
 
         for side in self.outer_sides:
-            assert ~ax2.spines[side].get_visible()
+            assert not ax2.spines[side].get_visible()
         for side in self.inner_sides:
             assert ax2.spines[side].get_visible()
 
@@ -325,8 +331,7 @@ def test_locator_to_legend_entries():
     locator = mpl.ticker.LogLocator(numticks=5)
     limits = (5, 1425)
     levels, str_levels = utils.locator_to_legend_entries(locator, limits, int)
-    if Version(mpl.__version__) >= Version("3.1"):
-        assert str_levels == ['10', '100', '1000']
+    assert str_levels == ['10', '100', '1000']
 
     limits = (0.00003, 0.02)
     _, str_levels = utils.locator_to_legend_entries(locator, limits, float)
@@ -407,8 +412,8 @@ def test_move_legend_grid_object(long_df):
     assert g.legend.get_title().get_text() == hue_var
     assert g.legend.get_title().get_size() == fontsize
 
-    assert g.legend.legendHandles
-    for i, h in enumerate(g.legend.legendHandles):
+    assert get_legend_handles(g.legend)
+    for i, h in enumerate(get_legend_handles(g.legend)):
         assert mpl.colors.to_rgb(h.get_color()) == mpl.colors.to_rgb(f"C{i}")
 
 
@@ -425,6 +430,28 @@ def test_move_legend_input_checks():
         utils.move_legend(ax.figure, "best")
 
 
+def test_move_legend_with_labels(long_df):
+
+    order = long_df["a"].unique()
+    labels = [s.capitalize() for s in order]
+    ax = scatterplot(long_df, x="x", y="y", hue="a", hue_order=order)
+
+    handles_before = get_legend_handles(ax.get_legend())
+    colors_before = [h.get_markerfacecolor() for h in handles_before]
+    utils.move_legend(ax, "best", labels=labels)
+    _draw_figure(ax.figure)
+
+    texts = [t.get_text() for t in ax.get_legend().get_texts()]
+    assert texts == labels
+
+    handles_after = get_legend_handles(ax.get_legend())
+    colors_after = [h.get_markerfacecolor() for h in handles_after]
+    assert colors_before == colors_after
+
+    with pytest.raises(ValueError, match="Length of new labels"):
+        utils.move_legend(ax, "best", labels=labels[:-1])
+
+
 def check_load_dataset(name):
     ds = load_dataset(name, cache=False)
     assert isinstance(ds, pd.DataFrame)
@@ -441,14 +468,14 @@ def check_load_cached_dataset(name):
         assert_frame_equal(ds, ds2)
 
 
-@_network(url="https://github.com/mwaskom/seaborn-data")
+@_network(url=DATASET_NAMES_URL)
 def test_get_dataset_names():
     names = get_dataset_names()
     assert names
     assert "tips" in names
 
 
-@_network(url="https://github.com/mwaskom/seaborn-data")
+@_network(url=DATASET_NAMES_URL)
 def test_load_datasets():
 
     # Heavy test to verify that we can load all available datasets
@@ -459,7 +486,7 @@ def test_load_datasets():
         check_load_dataset(name)
 
 
-@_network(url="https://github.com/mwaskom/seaborn-data")
+@_network(url=DATASET_NAMES_URL)
 def test_load_dataset_string_error():
 
     name = "bad_name"
@@ -548,6 +575,23 @@ def test_assign_default_kwargs():
     assert kws == {"c": 3, "d": 2}
 
 
+def test_check_argument():
+
+    opts = ["a", "b", None]
+    assert _check_argument("arg", opts, "a") == "a"
+    assert _check_argument("arg", opts, None) is None
+    assert _check_argument("arg", opts, "aa", prefix=True) == "aa"
+    assert _check_argument("arg", opts, None, prefix=True) is None
+    with pytest.raises(ValueError, match="The value for `arg`"):
+        _check_argument("arg", opts, "c")
+    with pytest.raises(ValueError, match="The value for `arg`"):
+        _check_argument("arg", opts, "c", prefix=True)
+    with pytest.raises(ValueError, match="The value for `arg`"):
+        _check_argument("arg", opts[:-1], None)
+    with pytest.raises(ValueError, match="The value for `arg`"):
+        _check_argument("arg", opts[:-1], None, prefix=True)
+
+
 def test_draw_figure():
 
     f, ax = plt.subplots()
@@ -573,3 +617,16 @@ def test_deprecate_ci():
     with pytest.warns(FutureWarning, match=msg + r"\('ci', 68\)"):
         out = _deprecate_ci(None, 68)
     assert out == ("ci", 68)
+
+
+def test_version_predates():
+
+    mock = ModuleType("mock")
+    mock.__version__ = "1.2.3"
+
+    assert _version_predates(mock, "1.2.4")
+    assert _version_predates(mock, "1.3")
+
+    assert not _version_predates(mock, "1.2.3")
+    assert not _version_predates(mock, "0.8")
+    assert not _version_predates(mock, "1")
